from loguru import logger
from dataherb.parse.model import MetaData


if __name__ == "__main__":
    logger.debug("End of Game")
